# Outputs

ThermalNetwork updates values in a system parameters file by using [GHEDesigner](https://github.com/BETSRG/GHEDesigner) to properly size the boreholes for the loads described in the [inputs](inputs.md).
